SystemOrganization addCategory: #ConfigurationOfRefactoringTools!

Object subclass: #ConfigurationOfRefactoringTools
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRefactoringTools'!

!ConfigurationOfRefactoringTools class methodsFor: 'private' stamp: 'topa 4/15/2015 16:56'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfRefactoringTools class methodsFor: 'private' stamp: 'topa 4/15/2015 16:57'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemtalksystems.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemtalksystems.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfRefactoringTools class methodsFor: 'metacello tool support' stamp: 'topa 4/15/2015 16:56'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRefactoringTools class methodsFor: 'metacello tool support' stamp: 'topa 4/15/2015 16:56'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfRefactoringTools class methodsFor: 'metacello tool support' stamp: 'topa 4/15/2015 16:56'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfRefactoringTools class methodsFor: 'accessing' stamp: 'topa 4/15/2015 16:56'!
project

	^self new project! !

!ConfigurationOfRefactoringTools methodsFor: 'baselines' stamp: 'topa 4/15/2015 17:12'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemtalksystems.com/ss/RefactoringToolsForSqueak'];
		yourself.
	
	spec for: #squeak do: [
		spec
			project: 'RefactoringBrowser' with:[
				spec 
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec 
			package: 'RefactoringTools' with: [spec requires: 'RefactoringBrowser'];
			yourself.

		spec
			group: 'default' with: #('RefactoringTools' );
			yourself]
		yourself.! !

!ConfigurationOfRefactoringTools methodsFor: 'accessing' stamp: 'topa 4/15/2015 16:56'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfRefactoringTools methodsFor: 'symbolic versions' stamp: 'mt 9/25/2017 10:38'!
release10: spec 
	<symbolicVersion: #release10>
	
	spec for: #'squeak' version: '1.0.1'.! !

!ConfigurationOfRefactoringTools methodsFor: 'symbolic versions' stamp: 'mt 9/5/2019 10:22'!
release20: spec 
	<symbolicVersion: #release20>
	
	spec for: #'squeak' version: '2.0'.! !

!ConfigurationOfRefactoringTools methodsFor: 'symbolic versions' stamp: 'mt 9/5/2019 10:21'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak5.1.x' version: #'release10'.
	spec for: #'squeak5.2.x' version: #'release10'.
	
	spec for: #'squeak5.3.x' version: #'release20'.! !

!ConfigurationOfRefactoringTools methodsFor: 'versions' stamp: 'mt 9/25/2017 10:38'!
version101: spec
	<version: '1.0.1' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'mt'.
		spec timestamp:  '9/25/2017 10:38'"printIt: [MetacelloPlatform current timestamp]".
		spec description: 'Bugfix release 1.0.1 of this project '].

	spec for: #squeak do: [	
		spec 
			project: 'RefactoringBrowser' with: #'stable';
			package: 'RefactoringTools' with: 'RefactoringTools-mt.3';
			yourself];
		yourself
! !

!ConfigurationOfRefactoringTools methodsFor: 'versions' stamp: 'topa 4/15/2015 17:09'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'topa'.
		spec timestamp: '4/15/2015 16:59'"printIt: [MetacelloPlatform current timestamp]".
		spec description: 'First release 1.0 of this project '].

	spec for: #squeak do: [	
		spec 
			project: 'RefactoringBrowser' with: #'stable';
			package: 'RefactoringTools' with: 'RefactoringTools-topa.2';
			yourself];
		yourself
! !

!ConfigurationOfRefactoringTools methodsFor: 'versions' stamp: 'mt 9/5/2019 10:38'!
version20: spec
	<version: '2.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'mt'.
		spec timestamp:  '9/5/2019 10:18'"printIt: [MetacelloPlatform current timestamp]".
		spec description: 'Use updated RefactoringBrowser for Squeak 5.3 and newer.'].

	spec for: #squeak do: [	
		spec 
			project: 'RefactoringBrowser' with: '3.0';
			package: 'RefactoringTools' with: 'RefactoringTools-mt.3';
			yourself];
		yourself
! !
